# \donttest{
data("eusilcA_pop")
data("eusilcA_smp")
ebp_model <- ebp(
fixed = eqIncome ~ gender + eqsize + cash + self_empl +
unempl_ben + age_ben + surv_ben + sick_ben + dis_ben + rent + fam_allow +
house_allow + cap_inv + tax_adj,
pop_data = eusilcA_pop, pop_domains = "district",
smp_data = eusilcA_smp, smp_domains = "district", L = 2,
weights = "weight", weights_type = "nlme", na.rm = TRUE,
pop_weights = "hhsize")
# full data of highest population below threshold by rank (descending order)
ebp_report_byrank(model = ebp_model,
pop_data = eusilcA_pop,
pop_domains = "district",
pop_weights = "hhsize")
# full data of highest rate below threshold by rank (descending order)
ebp_report_byrank(model = ebp_model,
pop_data = eusilcA_pop,
pop_domains = "district",
pop_weights = "hhsize",
byrank_indicator = "rate")
# bottom 10 poverty count below threshold by rank (in ascending order)
ebp_report_byrank(model = ebp_model,
pop_data = eusilcA_pop,
pop_domains = "district",
pop_weights = "hhsize",
number_to_list = 10,
head = FALSE)
# }
Run the code above in your browser using DataLab